% A Detector for Transients in 1/f Noise: MATLAB Routines
% Note: these routines are to be used in conjunction with the
% WAVELAB (UNIX version .701) software package and the MATLAB
% WAVELET toolbox. In particular, reference the "Stationary" subdirectory
% of the WAVELAB package.
%
% MAIN ROUTINES
%
% fig_vardet: 
%	show variation of E_k as function of DWT shift
%
% fig_vargam and fig_vargamplot.m:
%	show ratio of max E_k / min E_k as function of 
%	gamma and for various values of k
%
% fig_comppeaks
%	plot UDWT of C_2 scaling function and Gaussian
%       show the matching pattern coeficients for both.
%
% fig_showwfms
%	show C_2, Gaussian, and exponential waveforms
%
% fig_samplepath
%	show sample path of 1/f noise with C_2 scaling function
%
% detsim_plots3.m  and run_detsim3.m
% NOTE: First generate the desired data files with run_detsim3.m.
%       Then use detsim_plots3.m to plot the ROC curves.
%       The Monte Carlo simulations may take a while.
%
%	a) with doplot = [0 0 0 1], makes up ROC curves for
%	   C_2, Gaussian and exponential for k = 6,7,8
%	   data are generated by run_detsim3.m with
%	   testsets 1, 2 and 3
%
%  	b) with doplot = [0 1 0 0] makes up mismatch ROC curves
%          data are generated by run_detsim3.m with testsets
%	   4,5, and 6
%
%	c) with doplot = [0 0 1 0] makes up scale discrimination
%	    ROC curves
%	   data are generated by run_detsim3.m with testsets
%	   7,8 and 9
%
% UTILITY ROUTINES
%
% align_patterns:  apply scale dependnet offset to a stat pattern
% align_stat: align stationary wavelet table
% binary_inc: increments a binary number
% calc_msw: calculates variance of squared modulus
% circ_shift: circularly shifts a vector
% compute_dstat: computes shift dependent detection statistic
% dstat_pattern: returns SWT pattern that corresponds to index into TIWT table
% findlocalmax: finds local maxima
% j2str: make a vector of numbers into a string
% makephi: make up a scaling function
% makegauss: make up a gaussian function with same temporal width
%	     as a scaling function
% make2exp: make up a 2-sided exponential function with
%	    same temporal width as scaling function.
% make_1fnoise: make up 1/f noise 
% match_pat.c: a C-file that does pattern matching
% match_patterns.m: M-file counterpart (though much slower) of matchpat.c
% modulo_add: add an offset to a vector, modulo N
% mybin2dec: convert binary to decimal
% mydec2bin: convert decimal to binary
% no_blanks: get rid of blanks in a string
% plotroc: plots ROC curves
% plot_swt: plot UDWT with matching patterns superimposed
% run_detsimcore3: core program called by run_detsim3.m
% set_len:
% set_yticks:
% swt_offsets: determine offsets for peak aligned UDWT
% track_ridges2: track maxima ridges of UDWT
% upsamp: upsamples vector
% wsetup_axes: sets up axes for plotting
%
%
% MAT Files
%  seedmat: matrix of seeds for generating random vectors
%
%
% Copyright (c) 1998 Thomas T. Liu
% Send comments to ttliu@alpha.stanford.edu



 

