function stat_in = align_stat(stat_in,total_offset);
% align_stat --  Align stationary wavelet table so that the 
%                peaks of the transform approximately line up.
% Usage
%     stat_in = align_stat(stat_in,qmf)
%
% Inputs
%  stat_in 	input stationary wavelet transform table
%  total_offset vector of offsets generated by swt_offsets
%
% Outputs
%  stat_in   	output stationary wavelet transform table
%		with peaks approximately aligned.
%
% See Also
%   circ_shift, swt_offsets
%
% Example
%    offset = swt_offsets(qmf,M);
%    statout = align_stat(statin,-offset);

	[n,M] = size(stat_in);
	M = M-1;

	for m = 1:M
          stat_in(:,m+1) = circ_shift(stat_in(:,m+1),total_offset(m+1));
	end

        stat_in(:,1) = circ_shift(stat_in(:,1),total_offset(1)); 


% Copyright (c) 1998. Thomas T. Liu
%
% Note this function works in conjunction with
% routines and data structures from Wavelab version .701 which is copyrighted
% material from D.L. Donoho's group at Stanford University. 
