function makepattern(pattype,N,M,NumInPat,gamma0,Kvec);

% makepattern -- make matching patterns
%
% Usage
%
%     makepattern(pattype,N,M,NumInPat,gamma0,Kvec);
%
% Inputs
%
%  patttype		1: C2 scaling function 2: gaussian 3:exponential
%  N			length of signal; default 2^14
%  M			number of analysis scales; default 10
%  NumInPat		number of coefficients in pattern; default 20
%  gamma0		1/f noise exponent; default 1.0
%  Kvec			range of model scales; default Kvec = [6:8]
%
% Outputs
%
%   Stores the pattern in an output file


% Default Values
  if ~exist('N')
   N = 2^14;
  end
  if ~exist('NumInPat')
   NumInPat = 20;
  end
  if ~exist('M')
    M = 10;
  end



  if ~exist('gamma0');
    gamma0 = 1.0;
  end
  if ~exist('Kvec')
   Kvec = [6:8];
  end

  if pattype == 1
    prefix = 'c2';
  elseif pattype ==2
    prefix = 'ga';
  elseif pattype == 3
    prefix = 'ex';
  elseif pattype == 4
    prefix = 'ga2';
  elseif pattype == 5
    prefix = 'ex2';
  end


  names = [];

  qmf = sqrt(2)*coifwavf('coif2');
  J = log2(N);
  L = J-M;
  for k = Kvec

    % make up the scaling function
    phi = makephi(qmf,k-1);

    % if necessary change it into a gaussian or exponential
    if pattype == 2 
      phi = makegauss(phi,1);
    elseif pattype == 3 
      phi = make2exp(phi,1);
    elseif pattype == 4
      phi = makegauss(phi,sqrt(2));
    elseif pattype == 5
      phi = make2exp(phi,sqrt(2));
    end





    philen = length(phi);
    [m,mi] = max(abs(phi));

    sig = zeros(N,1);
  
    span = (N/2-mi) + (1:philen);
    sig(span) = phi(:);
    [m,mi] = max(abs(sig));


    sti = FWT_TI(sig,L,qmf);

    dstat = compute_dstat(sti,gamma0);
    [m,mi ] = max(dstat)
    pattern = dstat_pattern(sti,mi,gamma0,0,NumInPat);


    E_k = sum(pattern(:,3).^2 .* 2.^(-gamma0*pattern(:,1)))
    ratio =  E_k/m*100

    if pattype > 1
     eval(sprintf('load c2patg%d',10*gamma0));
     eval(sprintf('bpattern = c2_%d;',k));
     base_E_k = sum(bpattern(:,3).^2 .* 2.^(-gamma0*bpattern(:,1)))
     scalefactor = sqrt(base_E_k/E_k); %reference pattern to C2 scaling function	
   else
     scalefactor = 1;
    end

    pattern(:,3) = scalefactor*pattern(:,3);
    eval([prefix,'_',num2str(k), ' = pattern;']);
    eval([prefix,'_',num2str(k), 'sc = scalefactor;']);


    eval(sprintf('names = [names %s %s%s_%d%s];',setstr(39),setstr(32),prefix,k,setstr(39)));
    eval(sprintf('names = [names %s %s%s_%dsc%s];',setstr(39),setstr(32),prefix,k,setstr(39)));
  end
 
 patgamma = gamma0;
 names = [names ' nref patgamma '];
 nref = N/2;
 eval(sprintf('save %spatg%d %s',prefix,10*gamma0,names));


% (c) 1998 Thomas T. Liu