function plot_swt(sig,swt,pattern,xax,mscales,toffset,mflag,swt2,sig2,fontsize);
%  plot_swt(sig,swt,pattern,xax,mscales,toffset,mflag,swt2,sig2,fontsize);
%
%  Inputs:
%
%	sig: input signal
%	swt: stationary wavelet transform (UDWT)
%	pattern: a matrix of matching patterns to plot on top of UDWT 
%       xax: limits on xaxis
%       mscales: analysis scales to plot
%	toffset: offset to time axis
%	mflag: if 1 adds text to matching pattern, if 0 no text
%	swt2: a second stationary wavelet transform
%	sig2: a second input signal
%	fontsize: fontsize to use in plots

	[n,M] =  size(swt);
       if ~exist('fontsize');
          fontsize = 8;
       end
       if ~exist('mscales')
	M = M-1;
	num_win = M+2;
        mscales = 1:M;
	plotcoarse = 1;
       else
	num_win = length(mscales)+1;
	plotcoarse = 0;
    
       end
       if ~exist('toffset')
	toffset = 0;
       end
       if ~exist('mflag');
	mflag = 0;
       end

        tvec = (0:(n-1))-toffset;


        wsetup_axes; hold on;

    
        if exist('pattern')
           numpatterns = size(pattern,2)/3;
           dopatterns = 1;
           linetypes = ['co';'m*';'gx';'r+'];
        else
	   dopatterns = 0;
        end         

        if ~exist('xax');
         xax = [0 n-1];
        end

	axes(ax(1));
        if exist('sig2');
          plot(tvec,sig,tvec,sig2,'-.');
          FULLSCALE = 1.2*max(abs([sig(:); sig2(:)]));

        else
          plot(tvec,sig);
          FULLSCALE = 1.2*max(abs(sig));
        end
	 setyticks;

         set(gca,'FontSize',fontsize,'FontName','Times');

        set(gca,'Xlim',xax);
	     set(gca,'XtickLabel',[]);
  	ylabel('signal');

        for mindex = 1:length(mscales)
         m = mscales(mindex);

         axes(ax(mindex+1));
         if exist('swt2');
           h = plot(tvec,swt(:,m+1),tvec,swt2(:,m+1),'-.');
           FULLSCALE = 1.2*max(abs([swt(:,m+1);swt2(:,m+1)]));
         else
           h = plot(tvec,swt(:,m+1));
           FULLSCALE = 1.2*max(abs(swt(:,m+1)));
         end



	 setyticks;


         set(gca,'FontSize',fontsize,'FontName','Times');
	 ylabel(['m  = ',num2str(m)]);

         if dopatterns
            hold on;
            for k = 1:numpatterns

               pattern_offset = (k-1)*3;
               use_ind = find(pattern(:,1+pattern_offset) == m);
               linetype = linetypes(rem(k-1,4)+1,:);

               if ~isempty(use_ind)
                  plot(pattern(use_ind,2+pattern_offset)-1-toffset,...
                    pattern(use_ind,3+pattern_offset),linetype);
	        if mflag
                   h = text(pattern(use_ind,2+pattern_offset)-1-toffset+15,...
                    pattern(use_ind,3+pattern_offset),...
		     int2mat(use_ind));
		   set(h,'FontSize',fontsize,'FontName','Times');
	        end
 	       end
            end
  	   end
          
          set(gca,'Xlim',xax);
         
          xticks = get(gca,'XTick');
	  if mindex == length(mscales)
          xticklabels = get(gca,'XTickLabel');
          numticks = length(xticks);
          set(gca,'XTick',xticks(2:(numticks-1)));
          set(gca,'XTickLabel',xticklabels(2:(numticks-1),:));
	   xticks
	   else
	     set(gca,'XtickLabel',[]);
	   end
          end

	if plotcoarse        
         axes(ax(M+2));
         h = plot(tvec,swt(:,1));
         set(gca,'FontSize',fontsize);
         set(gca,'Xlim',xax);
	end



% Copyright (c) 1998 Thomas T. Liu





