% Script file: run_detsim.m
% Detector Performance Simulations
%
% Usage:  assign testsetvec with the desired testset numbers
%         e.g. to generate data for ROC curves for C_2 
%	  with input scales of k = 6,7,8 
%	  assign testsetvec = [1], then execute run_detsim3
%	  See Contents.m for a description of which test sets
%	  correspond to the data used to make the figures in the paper.
%
% uses: coifwavf, swt_offsets, align_patterns, makephi, makegauss,
%       make2exp, make_1fnoise, TI2Stat, FWT_TI, align_stat
%	run_detsimcore3


	direcname = 'matfiles/';

        %%%%%%%%%%%%%%%%%%%%%
	% General Parameters
        %%%%%%%%%%%%%%%%%%%%%
        N = 2^14;
	gamma = 1;gstr = sprintf('%d',10*gamma);
	h = 1.5;
	fmin = 1e-3;
	fmax = 5;
	Fs = 40;

        numtrials = 200;

        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% Wavelet Analysis Parameters
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	qmf = sqrt(2)*coifwavf('coif2');
  	M = 10;K0 = 7;
	K = 7;
	J = log2(N);
	L = J-M;

        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % Matching Parameters
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	matchscales = [6:8];
	nummatch = length(matchscales);
	absiprod_on = 0;

	scalerange = [6:10];
	cthresh = 2;
	rdelay = [-10:1:10];
	ndelay = length(rdelay);

	delays = [(-N/2+1):N/2];
	mode = 1;
	thisnref = N/2;



	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% load in patterns and random number seeds
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	load seedmat
	eval(sprintf('load c2patg%s',gstr));
	eval(sprintf('load gapatg%s',gstr));
	eval(sprintf('load expatg%s',gstr));
	offsets = swt_offsets(qmf,M);

	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %test run parameters
        % determine which signals and matching patterns to use
        % code
        % 0: C2 scaling function
        % 1: Gaussian with same variance as C2
        % 2: 2-sided exponentail with same var. as C2
        % 3: Gaussian with sqrt(2)*t scaling 
        % 4: 2-sided exp with sqrt(2)*t scaling
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   for testset = testsetvec

		testset
	if testset == 0

	matching_param = [0 ];
        signal_param  = [0 ];
        nosig_param = [ 1 ];
        kvec = [7 ];
        ktrack1vec = [6:10]
	dvec = [5 ];
	basefile = [direcname,'ds3bk7g1d5c2c2.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];


	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% TEST SET 1
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        elseif testset == 1
	matching_param = [0 0 0 0 0 0];
        signal_param  = [0 0 0 0 0 0];
        nosig_param = [ 1 0 0 0 0 0 ];
        kvec = [7 7 6 6 8 8];
        ktrack1vec = [6:10]
	dvec = [5 4 5 4 5 4];
	basefile = [direcname,'ds3bk7g1d5c2c2.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];

	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% TEST SET 2
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

        elseif testset == 2
	matching_param = [1 1 1 1 1 1 ];
        signal_param  = [1 1 1 1 1 1 ];
        nosig_param = [ 1 0 0 0 0 0 ];
        kvec = [7 7 6 6 8 8];
        ktrack1vec = [6:10]
	dvec = [5 4 5 4 5 4];
	basefile = [direcname,'ds3bk7g1d5gg.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];

        elseif testset == 3
	matching_param = [1 1 1 1 1 1 ]*2;
        signal_param  = [1 1 1 1 1 1 ]*2;
        nosig_param = [ 1 0 0 0 0 0 ];
        kvec = [7 7 6 6 8 8];
        ktrack1vec = [6:10]
	dvec = [5 4 5 4 5 4];
	basefile = [direcname,'ds3bk7g1d5ee.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];


        elseif testset == 4
	matching_param = [0 0 0 0 ];
        signal_param  = [1 1 2 2 ];
        nosig_param = [ 0 0 0 0 ];
        kvec = [7 7 7 7];
        ktrack1vec = [6:10]
	dvec = [5 4 5 4 ];
	basefile = [direcname,'ds3bk7g1d5c2c2.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];


        elseif testset == 5
	matching_param = [1 1]
        signal_param  = [3 3];
        nosig_param = [ 0 0 ];
        kvec = [7 7];
        ktrack1vec = [6:10]
	dvec = [5 4 ];
	basefile = [direcname,'ds3bk7g1d5gg.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];

        elseif testset == 6
	matching_param = [2 2]
        signal_param  = [4 4];
        nosig_param = [ 0 0 ];
        kvec = [7 7];
        ktrack1vec = [6:10]
	dvec = [5 4 ];
	basefile = [direcname,'ds3bk7g1d5ee.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];


        elseif testset == 7
	matching_param = [0 0 0 0]
        signal_param  = [0 0 0 0 ];
        nosig_param = [ 0 0 0 0 ];
        kvec = [5 5 4 4 ];
        ktrack1vec = [6:10]
	dvec = [5 4 5 4 5 4];
	basefile = [direcname,'ds3bk7g1d5c2c2.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];

        elseif testset == 8
	matching_param = [1 1];
        signal_param  = [ 3 3 ];
        nosig_param = [ 0 0 ];
        kvec = [ 6 6 ];
        ktrack1vec = [6:10]
	dvec = [5 4 ];
	basefile = [direcname,'ds3bk7g1d5gg.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];

        elseif testset == 9
	matching_param = [1 1];
        signal_param  = [ 1 1];
        nosig_param = [ 0 0 ];
        kvec = [ 4 4 ];
        ktrack1vec = [6:10]
	dvec = [5 4 ];
	basefile = [direcname,'ds3bk7g1d5gg.mat'];
        testsuite1 = [1:10];
	detwidthvec = [100 50 25];


        end





  varnames = [];
  for detwidth = detwidthvec

   varnames = [varnames sprintf(' det_stat%d est_scale%d est_delay%d ',...
	detwidth, detwidth,detwidth)];
  end
  varnames = [varnames,' pat7 phi0  numhits numsearch numsearch2 nmaxatktrack1'];
  


   for parind = 1:length(matching_param)

	eval(['clear ',varnames]);

	d = dvec(parind);
        matchpar = matching_param(parind);
        sigpar =   signal_param(parind);
        if (sigpar == 3) | (sigpar == 4)
	 optscale = sqrt(2);
        else
         optscale = 1;
        end
        do_nosig = nosig_param(parind);
        K = kvec(parind);



	for mscale = matchscales
	  mweight = 2^(gamma*(mscale-K0)/2);

          if matchpar == 0
           eval(sprintf('load c2patg%s',gstr));
           eval(['pattern = c2_',num2str(mscale),';']);
          elseif matchpar == 1
           eval(sprintf('load gapatg%s',gstr));
           eval(['pattern = ga_',num2str(mscale),';']);
          elseif matchpar == 2
           eval(sprintf('load expatg%s',gstr));
           eval(['pattern = ex_',num2str(mscale),';']);
          elseif matchpar == 3
           eval(sprintf('load ga2patg%s',gstr));
           eval(['pattern = ga2_',num2str(mscale),';']);
          elseif matchpar == 4
           eval(sprintf('load ex2patg%s',gstr));
           eval(['pattern = ex2_',num2str(mscale),';']);
	  else 
	   error('invalid matchpar');
          end


	  pattern(:,3) = pattern(:,3)*mweight;
	  eval(['pat',num2str(mscale),' = align_patterns(pattern,N,-offsets);']);        
	end

        poffset = thisnref - nref; % nref is a variable from cpatp
			           % and is the peak location of the scaling
				   % function used to make the pattern.




 	%%%%%%%%%%%%%%%%%%%%%%%        
        %make up the signal
 	%%%%%%%%%%%%%%%%%%%%%%%        

	weight  = 2^(gamma*(K-K0)/2);        
        if sigpar == 0
           phi0 = weight*makephi(qmf,K-1);	
        elseif sigpar == 1
          eval(sprintf('load gapatg%s',gstr));
          eval(['gsc = ga_',num2str(K),'sc;']);
          phi0 = weight*gsc*makegauss(makephi(qmf,K-1),optscale);	
    	elseif sigpar == 2
          eval(sprintf('load expatg%s',gstr));
          eval(['gsc = ex_',num2str(K),'sc;']);
          phi0 = weight*gsc*make2exp(makephi(qmf,K-1),optscale);	
        elseif sigpar == 3
          eval(sprintf('load ga2patg%s',gstr));
          eval(['gsc = ga2_',num2str(K),'sc;']);
          phi0 = weight*gsc*makegauss(makephi(qmf,K-1),optscale);	
        elseif sigpar == 4
          eval(sprintf('load ex2patg%s',gstr));
          eval(['gsc = ex2_',num2str(K),'sc;']);
          phi0 = weight*gsc*make2exp(makephi(qmf,K-1),optscale);	
        else
          error('invalid sigpar');
        end

        philen = length(phi0);
	[m,mi] = max(abs(phi0));
        span = (N/2-mi) + (1:philen);



        sigamp = d/12.4164;
	phi = phi0*sigamp;
	numtests = length(testsuite1)


	if do_nosig == 0 % don't need to do no signal case since
		         % it's already in the basefile
	  disp('loading basefile');
	  eval(['load ',basefile]);
	  for detwidth = detwidthvec
	    eval(sprintf('ds%d = det_stat%d;',detwidth,detwidth));
	    eval(sprintf('es%d = est_scale%d;',detwidth,detwidth));
	    eval(sprintf('ed%d = est_delay%d;',detwidth,detwidth));

          end
          nh = numhits;
          nsch = numsearch;
          nsch2 = numsearch2;
          nmaxt = nmaxatktrack1;
        end


	numhits = zeros(numtrials,length(detwidthvec)*2);
        numsearch = numhits;
        nmaxatktrack1 = zeros(numtrials,2);

        if do_nosig == 0
          numhits(:,1:2:2*length(detwidthvec)) = nh(:,1:2:2*length(detwidthvec));
	  numsearch(:,1:2:2*length(detwidthvec)) = nsch(:,1:2:2*length(detwidthvec));
	  numsearch2(:,1:2:2*length(detwidthvec)) = nsch2(:,1:2:2*length(detwidthvec));
          nmaxatktrack1(:,1) = nmaxt(:,1);
	end


	for detwidth = detwidthvec
          eval(sprintf('det_stat%d = zeros(numtrials,2*numtests);',detwidth));
          eval(sprintf('est_delay%d = zeros(numtrials,2*numtests);',detwidth));
          eval(sprintf('est_scale%d = zeros(numtrials,2*numtests);',detwidth));


	  if do_nosig == 0
	    eval(sprintf('det_stat%d(:,1:2:2*numtests) = ds%d(:,1:2:2*numtests);',detwidth,detwidth));
	    eval(sprintf('est_delay%d(:,1:2:2*numtests) = ed%d(:,1:2:2*numtests);',detwidth,detwidth));
	    eval(sprintf('est_scale%d(:,1:2:2*numtests) = es%d(:,1:2:2*numtests);',detwidth,detwidth));
    	  end
        end
   


        for trial = 1:numtrials;
                trial
		randn('seed',seeds(trial));
	

		sig = make_1fnoise(randn(N,1),gamma,h,fmin,fmax,Fs);

		if do_nosig 
		        stat = TI2Stat(FWT_TI(sig,L,qmf));
			stat = align_stat(stat,-offsets);
			toff = 1;

	          detind = 0;
		 maxhits = [];
	         for ktrack1 = ktrack1vec
 	            maxhits = [maxhits findlocalmax(stat(:,ktrack1+1),absiprod_on)];
		 end
		nmaxatktrack1(trial,1) = length(maxhits);


	          for detwidth = detwidthvec
	             detind = detind+1;
		     run_detsimcore3;
                  end




		end

                %compute value of statistic on signal and noise

                sig(span) = sig(span) + phi(:);
                stat = TI2Stat(FWT_TI(sig,L,qmf));
		stat = align_stat(stat,-offsets);
		toff = 2;

		maxhits = [];

		for ktrack1 = ktrack1vec
   	         maxhits = [maxhits findlocalmax(stat(:,ktrack1+1),absiprod_on)];
		end
		nmaxatktrack1(trial,2) = length(maxhits);

		detind = 0;
	        for detwidth = detwidthvec
		 detind = detind+1;
		 run_detsimcore3;
                end




	end

        if absiprod_on
	   matname = [direcname,'ds3ak',num2str(K),...
 	  'g',num2str(gamma),'d',num2str(d)];
         else
	   matname = [direcname,'ds3bk',num2str(K),...
	  'g',num2str(gamma),'d',num2str(d)];
         end
  
	 if sigpar == 0
	   matname = [matname,'c2'];
         elseif sigpar == 1
	   matname = [matname,'g'];
         elseif sigpar == 2
	   matname = [matname,'e'];
         elseif sigpar == 3
	   matname = [matname,'g2'];
         elseif sigpar == 4
	   matname = [matname,'e2'];
	 end


	 if matchpar == 0
	   matname = [matname,'c2'];
         elseif matchpar == 1
	   matname = [matname,'g'];
         elseif matchpar == 2
	   matname = [matname,'e'];
         elseif matchpar == 3
	   matname = [matname,'g2'];
         elseif matchpar == 4
	   matname = [matname,'e2'];
	 end

	if numtrials ~= 200
	 matname = [matname,'n',num2str(numtrials)];
	end
     
	disp('saving results');
	matname
	eval(['save -v4 ',matname,varnames]);




end

end


% Copyright (c) 1998 Thomas T. Liu

