function offsets = swt_offsets(qmf,M)

% swt_offset: generates offsets to align UDWT
%
% Usage
%    offsets = swt_offsets(qmf,M)
%
% Inputs
%  qmf		qmf filter coefficients
%  M    	number  of analysis scales
%
% Outputs
%  offsets	vector of offsets for each analysis scale

        offsets = NaN*ones(M+1,1);
	[m,rlo_peak] =  max(abs(qmf));
        rlo_peak = rlo_peak-1;
	alo_peak = -rlo_peak
        ahi_peak = rlo_peak-1

        scale_offset = 0;
	for scale = 1:M
        % offset due to filters    
          filt_offset = ahi_peak*2^(scale-1) + alo_peak*(sum(2.^(0:(scale-2))));
        % offset due to causal implementation of stat table (see ti_2_stat.m) 
	  scale_offset = scale_offset + 2^(scale-1);

          offsets(scale+1,1) = scale_offset + filt_offset;
        end

          filt_offset = alo_peak*(sum(2.^(0:(scale-1))));
          offsets(1,1) = scale_offset + filt_offset;



% Copyright (c) 1998 Thomas T. Liu
